#
# spec file for package gala
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define         sover 0
%define         appid io.elementary.desktop.wm
Name:           gala
Version:        8.0.4
Release:        1.1
Summary:        The Pantheon window manager
License:        GPL-3.0-or-later
URL:            https://github.com/elementary/gala
Source0:        %{url}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  desktop-file-utils
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  vala
BuildRequires:  valadoc
BuildRequires:  valadoc-doclet-html
BuildRequires:  pkgconfig(gee-0.8)
BuildRequires:  pkgconfig(glib-2.0)
BuildRequires:  pkgconfig(gnome-desktop-3.0)
BuildRequires:  pkgconfig(granite)
BuildRequires:  pkgconfig(granite-7)
BuildRequires:  pkgconfig(gtk+-3.0)
BuildRequires:  pkgconfig(gtk4)
BuildRequires:  pkgconfig(libcanberra)
BuildRequires:  pkgconfig(libhandy-1)
%if 0%{?suse_version} < 1600
BuildRequires:  pkgconfig(libmutter-13)
%else
BuildRequires:  pkgconfig(libmutter-15)
%endif
BuildRequires:  pkgconfig(sqlite3)

%description
Gala is a window and compositing manager based on libmutter. It manages the
various windows a user has open.

It takes care of behaviors such as moving windows around, window switching,
window overview, animating windows, maximization, multiple workspaces,
providing accessibility features like zoom, and more.

%package -n     lib%{name}%{sover}
Summary:        Gala is a library for Elementary development
Group:          System/Libraries

%description -n lib%{name}%{sover}
Gala is a window and compositing manager based on libmutter. It manages the
various windows a user has open.

%package        plugins
Summary:        A collection of plugins for %{name}
Requires:       %{name} = %{version}

%description    plugins
Gala is a window and compositing manager based on libmutter. It manages the
various windows a user has open.

This package contains a collection of plugins: zoom, notify, maskcorners etc.

%package        devel
Summary:        Gala development library -- Development files
Requires:       lib%{name}%{sover} = %{version}

%description    devel
Gala is a window and compositing manager based on libmutter. It manages the
various windows a user has open.

This package contains the development files for %{name}

%lang_package

%prep
%autosetup

%if 0%{?suse_version} < 1600
#fix Leap, as there is no valacheck
sed -i -e 's|pid_t|int|g' vapi/libmutter.vapi lib/App.vala src/WindowTracker.vala
%endif

%build
export CFLAGS="%{optflags} -Wno-error=return-type"
%meson \
  -Ddocumentation=false \
  -Dsystemd=true
%meson_build

%install
%meson_install
%find_lang %{name} %{?no_lang_C}
%fdupes -s %{buildroot}

%ldconfig_scriptlets -n lib%{name}%{sover}

%files
%license COPYING
%doc AUTHORS README.md
%{_datadir}/metainfo/%{name}.metainfo.xml
%{_datadir}/glib-2.0/schemas/20_elementary.pantheon.wm.gschema.override
%{_datadir}/glib-2.0/schemas/org.pantheon.desktop.%{name}.gschema.xml
%{_datadir}/applications/%{name}{,-multitaskingview,-other,-wayland}.desktop
%{_bindir}/%{name}{,-daemon,-daemon-gtk3}
%{_userunitdir}/io.elementary.gala.target
%{_userunitdir}/io.elementary.gala@wayland.service
%{_userunitdir}/io.elementary.gala@x11.service
%{_sysconfdir}/xdg/%{appid}.shell

%files -n lib%{name}%{sover}
%{_libdir}/lib%{name}.so.*

%files plugins
%{_libdir}/%{name}

%files devel
%{_datadir}/vala/vapi/%{name}.{deps,vapi}
%{_libdir}/pkgconfig/%{name}.pc
%{_libdir}/lib%{name}.so
%{_includedir}/%{name}

%files lang -f %{name}.lang

%changelog
* Mon Dec  2 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.4:
  * Improved shadows performance
  * Updated Translations
* Mon Nov 25 2024 Richard Rahl <rrahl0@opensuse.org>
- small fix for Leap 1500
* Mon Nov 25 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.3:
  * DragDropAction: Fix actor_clicked emission on touch event
  * Introduce AnimationsSettings
  * DragDropAction: properly handle button release event
  * Introduce a WindowPositioner
  * Pass Meta.Display instead of Gala.WindowManager where possible
  * Add support for Mutter47
  * AnimationSettings: Introduce get_animation_duration
  * HideTracker: Take windows that are only vertically maximized
  * Add panel hide delay
- update to 8.0.2:
  * WindowIcon: reload icon if more info about the window becomes available
  * ManagedClient: Inherit fds
  * Fix autohide
  * Fix stacking order after workspace switch
  * ScreenshotManager: Fix cursor inclusion for non window screenshots
  * Fix panel sometimes being behind windows
- remove support-libmutter15.patch, as upstream integrated the patch
* Wed Nov 20 2024 Richard Rahl <rrahl0@opensuse.org>
- move Leap16 to libmutter-15
* Thu Oct 31 2024 Richard Rahl <rrahl0@opensuse.org>
- add patch support-libmutter15.patch
- actually fix CFLAGS
* Tue Oct  8 2024 Richard Rahl <rrahl0@opensuse.org>
- leap16 needs libmutter-13 not libmutter-14
* Wed Sep 18 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.1:
  * Fix a potential crash when moving windows between workspaces
  * Fix notification animation when entering multitasking view
  * Updated translations
- remove patch fix-mutter45.patch as upstreamed applied the patch
* Fri Aug 23 2024 Richard Rahl <rrahl0@opensuse.org>
- Add patch fix-mutter45.patch for fixing build issues on Leap
* Wed Aug 21 2024 Richard Rahl <rrahl0@opensuse.org>
- update to 8.0.0:
  * IconGroup: remove close button
  * Remove workspace-switcher-background key
  * Remove expose-windows shortcut
  * Remember window position
  * Add "Switch windows" gesture
  * Animate nudge with clones
  * Improve debug messages in notifications stack and add more checks
  * BackgroundManager: Inline namespace
  * BackgroundManager: Don't position background actors
  * Round corners of workspaces in multitasking view
  * Revert "BackgroundManager: Don't position background actors"
  * Show notifications on the left in RTL languages
  * Add an option to disable hotcorners in fullscreen
  * Add support for Mutter 46
  * Remove content.set_rounded_clip_bounds
  * Use event time instead of META_CURRENT_TIME
  * switch_to_next_workspace: require timestamp
  * Add window spread for an app
  * Rework close button
  * Fix documentation
  * Daemon: Implement monitor labels
  * MonitorLabel: clean up styles, gtk4 prep
- update to 7.1.3:
  * Changing the wallpaper or going to sleep respects the "Reduce Motion" option
  * Use appropriate drag-and-drop pointers when moving windows
  * Fix the issue when gestures in the multitasking view might stop working
  * Improve dynamic workspaces behaviour with multiple monitors
  * Updated translations
- update to 7.1.2:
  * Improve handling of move-to-workspace shortcut
  * Fix moving maximized and fullscreen windows to new workspace on launch
  * Add shadow to wallpaper clones while switching workspace
  * Update gala.metainfo.xml.in
  * WindowManager: A small cleanup
  * Use dark wallpaper
  * Fix warnings
  * Use Meta.Window.is_on_primary_monitor ()
  * Kill workspace switch when opening multitasking view
- update to 7.1.1:
  * PiP: Check workspace before hiding the window
  * Keep track of dimmed windows
  * Revert "WindowManager: Remove Meta.Later"
  * WindowSwitcher: Remove dark style css_provider if theme changes
- update to 7.1.0:
  * Colorblind correction filters
  * ShadowEffect: Only use Gtk widgetry at the pain stage
  * Hardcode accent colors
  * Deduplicate ShadowEffect class
  * WindowClone: Use Gtk later
  * Tooltip: Use Gtk later
  * WindowSwitcher: Use Gtk later
  * WindowManager: Remove Meta.Later
  * Update Gala Systemd services
  * Metainfo Improvements
- update to 7.0.3:
  * WM: Add laters via compositor
  * maskcorners: Scale corner masks per-monitor
  * Utils: Remove bell
  * Enable Alt + ~ to switch between windows of the same application
  * DwellClickTimer: Support non-integer, monitor specific scales
  * ScreenshotManager: Support non-integer scaling factors
  * WM: Init things that depend on GTK later
  * KeyboardManager: Set keyboard layout on startup
  * HotCorners: Support floating point scale factors
  * WM: Drop Meta.ShadowFactory
  * IconGroup: Support floating scale factors
  * WorkspaceInsertThumb: Support floating point scale factors
  * Support floating point scale for resize button
  * NotificationStack: Support floating point scale factors
  * WindowSwitcher: Support floating point scale factors
  * InternalUtils: Remove pixel_align method, and just round
  * PiP PopupWindow: Support floating point scale factor
  * WorkspaceClone: Handle floating point scaling factors
  * WindowSwitcher: Fix rounded corners
  * WindowIconActor: Support setting floating point scale on placement
  * MultitaskingView: Ensure MonitorClones are visible on other monitors
  * WindowSwitcher: Merge icon and indicator
  * WindowSwitcher: Respect animations key
  * MultitaskingView: Support floating point scale factors
  * BackgroundManager: dark dim effect
  * Avoid to use Gdk constants when Clutter should be used
  * Window Dim: Use get_transient_for
  * WindowSwitcher: Improve keyboard navigation
- update to 7.0.2:
  * Use ClickAction for FramedBackground and close buttons
  * Remove texture.png
  * WindowOverview and WindowCloneContainer: Cleanup
  * WindowOverview: Use button_release_event
  * Avoid connecting multiple times to window_created
  * WindowClone: optimize ActiveShape
  * PointerLocator: Support floating, monitor specific scale
  * DnD: Don't disable reactivity
  * Don't manually map notifications while nudge animation is playing
  * PiP: Use constraints
- update to 7.0.1:
  * Allow KeyBindingAction.NONE in Multitasking View
  * Dialogs: Remove DBus Timeout From AccessDialog Call
  * WindowClone: Cleanup
  * Extend list of allowed keybindings in multitasking view
  * Allow zoom keybindings in multitasking view
  * PIP: Fix log spam
  * WindowClone: Add click action only in overview mode
  * WindowClone: Fix warnings in window overview
  * PiP: Respect animations key
  * Fix window maximize and unmaximize animations
  * IconGroup: Make close button respect animations key
- update to 7.0.0:
  * Reload animated wallpapers when timezone changes
  * Work around crash when receiving notifications
  * ShadowEffect: let Clutter know the shadow's size
  * Fix crash when monitor is turned off
  * Improve multitasking view animation performance
  * Fix workspace switching animation in multitasking view
- update to 6.3.3:
  * Updated translations
- update to 6.3.2
  * Use access portal for force quit
  * Updated translations
- update to 6.3.1:
  * Properly update accent color in the window switcher
  * Fix selecting windows underneath the window switcher
  * Prevent potential crashes
  * Resize workspaces when displays change
  * Handle windows with no title
  * Use access portal for display settings confirmation and force quit
  * Allow closing multitasking view with Super
  * Updated translations
- update to 6.3.0:
  * Fix shadow clipping on server-side decorated windows
  * Support for high-resolution scroll events
  * Redesigned Alt + Tab switcher
  * Dim the parents of modal dialogs
  * Dialogs fall down on parents instead of shooting out
  * Updated translations
- update to 6.2.1:
  * Fix a potential crash when taking screenshots
- update to 6.2.0:
  * Stash the picture-in-picture window by pushing it off screen
  * Fix a potential crash while changing wallpapers
- update to 6.0.1:
  * Include window decorations in screenshots for server-side decorated windows
- update to 6.0.0:
  * Add multitouch gestures
  * Show window titles in multitasking view
  * Close the Alt + Tab switcher by pressing Esc without releasing Alt
  * Increase maximum zoom level and provide feedback when unable to zoom
  * Show a context menu when secondary clicking the background
  * New Dwell Click and Locate Pointer animations
  * Add Take Screenshot to window context menu
  * Always play shutter sound when taking screenshots
  * Minor visual improvements
  * HiDPI fixes
  * Performance improvements
- update to 3.3.2:
  * Fix “Always on Visible Workspace” windows disappearing when changing workspaces
  * Fix windows on non-primary displays disappearing when changing workspaces
  * Updated translations
- update to 3.3.1:
  * Fix crash when changing workspaces while a transient window is opening
  * Updated translations
- update to 3.3.0:
  * Don't show Gala Background Services in the dock
  * Fixes for media key handling
  * Show keyboard shortcuts in HeaderBar menus
  * Updated translations
- update to 3.2.0:
  * Improve window shadows for legacy apps
  * Fix potential crash when taking screenshots
  * Fix notification position after changing DPI
  * Fix animations for moving and maximizing tiled windows
- switch url to github, as we don't want to link to a different OS
- remove patch 0001-port-to-mutter330.patch, as unneeded
* Thu Jul  4 2019 avvissu@yandex.by
- Update to version 0.3.1+git228.5f1dbf1:
  * Add scale factor to screenshot file (#489)
  * Prevent double BackgroundManager destroy (#562)
  * Add Silesian and update translation template
  * Only use cached buttons when height matches, fixing dpi switch issue (#480)
  * Fix minimize animation in HiDPI monitor (#164) (#541)
* Thu May 30 2019 avvissu@yandex.by
- Update to version 0.3.1+git223.3ae100d:
  * Fix app notification schema not being found (#524)
  * More usage of Utils.get_ui_scaling_factor() (#477)
  * Hide selection while dragging window clone in workspace-view (#526)
  * Allow <Enter> to leave workspace-view without selecting window (#525)
  * Do not try to move window to workspace which it is already on (#527)
  * Fix window menu sync (#532)
  * Constructors of abstract classes should not be public
  * Fix app switcher left and right padding (#479)
* Mon Mar  4 2019 opensuse-packaging@opensuse.org
- Update to version 0.3.1+git215.395670e:
  * Fixed saving screenshot to clipboard (#481)
  * windowswitcher: Update scale factor when updating dock (#471)
  * po: Update translations
  * pip: Change popup location to bottom right (#438)
  * Tile switching fix for position only changes (#387)
  * Allow to cancel screenshot when pressing ESC (#463)
  * Do not block stage drawing when saving the screenshots (#460)
  * screenshotmanager: Only create non-existing "Screenshots" subfolder in PICTURES (#462)
  * Save screenshots to (self created) screenshots folder (#459)
  * ScreenshotManager: implement flash_area and handle flash parameter (#147)
* Thu Nov 29 2018 Alexei Podvalsky <avvissu@yandex.by>
- Build with libmutter <= 3.28.3
* Thu Nov  8 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add regex for filtering provided libraries
* Tue Oct 30 2018 Alexei Podvalsky <avvissu@yandex.by>
- Add 0001-port-to-mutter330.patch
* Fri Jun  8 2018 avvissu@yandex.by
- Add _service file
- Add a new package with plugins
- Add SECTION: Fix desktopfile-without-binary rpmlint warning
- Fix: Icon will not found when changing the locale settings
- Spec file cleanup
* Mon Mar 19 2018 hillwood@opensuse.org
- Update version to 0.3.1
  * Use meson build system instead of autotools.
  * Add support for mutter 3.27.92
  * Make window-switcher compatible with HiDPI
  * screenshotmanager: Add support to handle include_cursor
  * gsettings: make window close duration shorter
  * vapi: Add libcanberra-gtk3 which is "actually not available"
  * meson: Add support for valadoc
  * meson: Fix build with libmutter-2
  * meson: Ensure RPATH is set after install
  * windowsmanager: Insert new workspace for fullscreen windows next to current one
  * windowmanager: Show a tile preview when tiling a window
* Mon Nov 13 2017 hillwood@opensuse.org
- Update to gita82bb34.
  * Support mutter 3.26
  * notify: Make notifications to be HiDPI compatible
  * build: Don't squash VALAFLAGS from the environment
  * maskcorners: Fix size of radius in HiDPI
  * workspacethumb: Fix offset of inserted window-icons
  * notify: Fix stroke width and border radius on HiDPI
  * multitaskingview: Ignore key/scroll-events while closing
  * readme: Add libxml2-utils as dependency
  * Update autogen command
  * screenshotmanager: Implement ScreenshotArea
- Fix "values extending the format should start with "X-"" rpmlint warning
- Fix desktopfile-without-binary rpmlint warning
* Tue Aug 22 2017 avvissu@yandex.by
- Switch mode to buildtime
* Sun Aug 20 2017 mailaender@opensuse.org
- Switch from tar_scm to obs_scm
- Switch from bzr to git repository
- Follow stable/loki branch instead of master/trunk
* Sun Jun  4 2017 avvissu@yandex.by
- Use _pattern instead of plank as required dependency
* Tue May 16 2017 avvissu@yandex.by
- Update to 0.3.0+bzr.568
- Use mutter-devel instead of pkconfig(style)
- Add sover macro
- Spec file cleanup
* Fri Nov 18 2016 avvissu@yandex.by
- Update to 0.3.0+bzr.547:
  * Drop stray clutter-gtk-1.0 reference
  * Add support for mutter 3.22
  * Upate mutter bindings to 3.22.2
  * Update translations
* Tue Sep 20 2016 avvissu@yandex.by
- Add Recommends: gala-lang
* Sun Sep 18 2016 avvissu@yandex.by
- Update to 0.3.0+bzr.539
- Spec file cleanup
- Remove required dependencies: mutter and libgala
- Use fdupes
* Fri May  6 2016 mailaender@opensuse.org
- update to version 0.3.0.bzr.518
* Sat Feb 27 2016 mailaender@opensuse.org
- update to version 0.2.0+freya.bzr.481
- disable GSettings schema compilation
* Sat Jan 30 2016 mailaender@opensuse.org
- require GNOME wallpapers to avoid a crash at first startup
* Sun May 10 2015 mailaender@opensuse.org
- update to the freya branch
* Fri May  9 2014 jengelh@inai.de
- initial packaging of the trunk series
